@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/* Copyright 2008,2009,2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,17 +18,17 @@
  */
 #include "KGpgKeyNode.h"
 
-#include <KLocale>
-
-#include "convert.h"
 #include "KGpgGroupMemberNode.h"
-#include "kgpginterface.h"
-#include "kgpgitemmodel.h"
-#include "kgpgsettings.h"
 #include "KGpgRootNode.h"
 #include "KGpgSubkeyNode.h"
 #include "KGpgUatNode.h"
 #include "KGpgUidNode.h"
+#include "convert.h"
+#include "kgpginterface.h"
+#include "kgpgsettings.h"
+#include "model/kgpgitemmodel.h"
+
+#include <KLocale>
 
 KGpgKeyNode::KGpgKeyNode(KGpgRootNode *parent, const KgpgCore::KgpgKey &k)
 	: KGpgSignableNode(parent),
@@ -148,9 +148,7 @@ KGpgKeyNode::getComment() const
 void
 KGpgKeyNode::readChildren()
 {
-	KgpgInterface *interface = new KgpgInterface();
-	KgpgCore::KgpgKey key = interface->readSignatures(this);
-	delete interface;
+	KgpgInterface::readSignatures(this);
 
 	m_signs = 0;
 	foreach(KGpgNode *n, children)
@@ -215,6 +213,7 @@ KGpgKeyNode::delRef(KGpgRefNode *node)
 {
 	Q_ASSERT(m_refs.indexOf(node) != -1);
 	m_refs.removeOne(node);
+	Q_ASSERT(m_refs.indexOf(node) == -1);
 }
 
 QList<KGpgGroupNode *>
@@ -334,16 +333,14 @@ bool
 KGpgKeyNode::compareId(const QString &other) const
 {
 	if (other.length() == m_key->fullId().length())
-		return (other.compare(m_key->fullId(), Qt::CaseInsensitive) == 0);
+		return other.compare(m_key->fullId(), Qt::CaseInsensitive);
 
 	if (other.length() == m_key->fingerprint().length())
-		return (other.compare(m_key->fingerprint(), Qt::CaseInsensitive) == 0);
+		return other.compare(m_key->fingerprint(), Qt::CaseInsensitive);
 
-	const QString comId = m_key->fullId().isEmpty() ? m_key->fingerprint() : m_key->fullId();
-
-	return (other.right(comId.length()).compare(
-			comId.right(other.length()),
-			Qt::CaseInsensitive) == 0);
+	return other.right(m_key->fullId().length()).compare(
+			m_key->fullId().right(other.length()),
+			Qt::CaseInsensitive);
 }
 
 void
