@@ -14,26 +14,27 @@
 
 #include "kgpgtextedit.h"
 
-#include <QDragEnterEvent>
-#include <QTextStream>
-#include <QDropEvent>
-#include <QFile>
-
-#include <kio/netaccess.h>
-#include <KMessageBox>
-#include <KLocale>
-
 #include "selectsecretkey.h"
 #include "kgpgsettings.h"
-#include "kgpgtextinterface.h"
 #include "keyservers.h"
-#include "kgpgeditor.h"
 #include "selectpublickeydialog.h"
 #include "detailedconsole.h"
-#include "kgpgdecrypt.h"
-#include "kgpgencrypt.h"
-#include "kgpgimport.h"
 #include "keysmanager.h"
+#include "editor/kgpgeditor.h"
+#include "transactions/kgpgdecrypt.h"
+#include "transactions/kgpgencrypt.h"
+#include "transactions/kgpgimport.h"
+#include "transactions/kgpgsigntext.h"
+#include "transactions/kgpgverify.h"
+
+#include <KLocale>
+#include <KMessageBox>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QFile>
+#include <QTextCodec>
+#include <QTextStream>
+#include <kio/netaccess.h>
 
 #define SIGNEDMESSAGE_BEGIN  QLatin1String( "-----BEGIN PGP SIGNED MESSAGE-----" )
 #define SIGNEDMESSAGE_END    QLatin1String( "-----END PGP SIGNATURE-----" )
@@ -215,13 +216,9 @@ void KgpgTextEdit::slotSign(const QString &message)
 
     delete opts;
 
-    QStringList options;
-    if (KGpgSettings::pgpCompatibility())
-        options << QLatin1String( "--pgp6" );
-
-    KGpgTextInterface *interface = new KGpgTextInterface();
-    connect(interface, SIGNAL(txtSigningFinished(QString)), SLOT(slotSignUpdate(QString)));
-    interface->signText(message, signkeyid, options);
+	KGpgSignText *signt = new KGpgSignText(this, signkeyid, message);
+	connect(signt, SIGNAL(done(int)), SLOT(slotSignUpdate(int)));
+	signt->start();
 }
 
 void KgpgTextEdit::slotVerify(const QString &message)
@@ -238,10 +235,9 @@ void KgpgTextEdit::slotVerify(const QString &message)
         return;
     posend += endmsg.length();
 
-    KGpgTextInterface *interface = new KGpgTextInterface();
-    connect(interface, SIGNAL(txtVerifyMissingSignature(QString)), SLOT(slotVerifyKeyNeeded(QString)));
-    connect(interface, SIGNAL(txtVerifyFinished(QString,QString)), SLOT(slotVerifySuccess(QString,QString)));
-    interface->verifyText(message.mid(posstart, posend - posstart));
+    KGpgVerify *verify = new KGpgVerify(this, message.mid(posstart, posend - posstart));
+    connect(verify, SIGNAL(done(int)), SLOT(slotVerifyDone(int)));
+    verify->start();
 }
 
 void KgpgTextEdit::slotDecryptDone(int result)
@@ -280,30 +276,52 @@ void KgpgTextEdit::slotEncodeUpdate(int result)
 	sender()->deleteLater();
 }
 
-void KgpgTextEdit::slotSignUpdate(const QString &content)
+void KgpgTextEdit::slotSignUpdate(int result)
 {
-    sender()->deleteLater();
-    if (content.isEmpty())
-    {
-        KMessageBox::sorry(this, i18n("Signing not possible: bad passphrase or missing key"));
-        return;
-    }
+	const KGpgSignText * const signt = qobject_cast<KGpgSignText *>(sender());
+	sender()->deleteLater();
+	Q_ASSERT(signt != NULL);
+
+	if (result != KGpgTransaction::TS_OK) {
+		KMessageBox::sorry(this, i18n("Signing not possible: bad passphrase or missing key"));
+		return;
+	}
+
+	const QString content = signt->signedText().join(QLatin1String("\n")) + QLatin1String("\n");
 
     setPlainText(content);
     emit resetEncoding(false);
 }
 
-void KgpgTextEdit::slotVerifySuccess(const QString &content, const QString &log)
+void KgpgTextEdit::slotVerifyDone(int result)
 {
-    sender()->deleteLater();
-    emit verifyFinished();
-    (void) new KgpgDetailedInfo(this, content, log, QStringList(), i18nc("Caption of message box", "Verification Finished"));
+	const KGpgVerify * const verify = qobject_cast<KGpgVerify *>(sender());
+	sender()->deleteLater();
+	Q_ASSERT(verify != NULL);
+
+	emit verifyFinished();
+
+	if (result == KGpgVerify::TS_MISSING_KEY) {
+		verifyKeyNeeded(verify->missingId());
+		return;
+	}
+
+	const QStringList messages = verify->getMessages();
+
+	if (messages.isEmpty())
+		return;
+
+	QStringList msglist;
+	foreach (QString rawmsg, messages)
+		msglist << rawmsg.replace(QLatin1Char('<'), QLatin1String("&lt;"));
+
+	(void) new KgpgDetailedInfo(this, KGpgVerify::getReport(messages, m_model),
+			msglist.join(QLatin1String("<br/>")),
+			QStringList(), i18nc("Caption of message box", "Verification Finished"));
 }
 
-void KgpgTextEdit::slotVerifyKeyNeeded(const QString &id)
+void KgpgTextEdit::verifyKeyNeeded(const QString &id)
 {
-    sender()->deleteLater();
-
     KGuiItem importitem = KStandardGuiItem::yes();
     importitem.setText(i18n("&Import"));
     importitem.setToolTip(i18n("Import key in your list"));
@@ -318,8 +336,6 @@ void KgpgTextEdit::slotVerifyKeyNeeded(const QString &id)
         kser->slotSetText(id);
         kser->slotImport();
     }
-    else
-        emit verifyFinished();
 }
 
 void KgpgTextEdit::slotSignVerify()
