@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2011,2012
+ *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 /***************************************************************************
  *                                                                         *
@@ -14,21 +15,20 @@
 #ifndef KEYSMANAGER_H
 #define KEYSMANAGER_H
 
+#include "ui_adduid.h"
+
+#include "core/kgpgkey.h"
+#include "model/kgpgitemmodel.h"
+#include "model/kgpgitemnode.h"
+
+#include <KDialog>
+#include <KToggleAction>
+#include <KUrl>
+#include <KXmlGuiWindow>
 #include <QClipboard>
 #include <QSet>
-
-#include <KToggleAction>
-#include <KXmlGuiWindow>
-#include <KDialog>
-#include <KUrl>
-
 #include <solid/networking.h>
 
-#include "kgpgkey.h"
-#include "ui_adduid.h"
-#include "kgpgitemmodel.h"
-#include "kgpgitemnode.h"
-
 class QEvent;
 
 class KSelectAction;
@@ -47,7 +47,6 @@ class KeyTreeView;
 class KGpgAddUid;
 class KGpgDelKey;
 class KGpgImport;
-class KGpgTextInterface;
 class KGpgTransactionJob;
 
 class KStatusNotifierItem;
@@ -139,7 +138,6 @@ private slots:
     void slotAddUidFin(int res);
     void slotDelPhotoFinished(int res);
     void quitApp();
-    void slotToggleSecret(bool);
     void slotShowLongId(bool);
     void slotSetTrustFilter(int);
     void slotGotoDefaultKey();
